@@ -1,6 +1,6 @@
 #!@PERL_COMMAND@
 
-# $Id: smbldap-config.pl 121 2011-10-07 05:40:06Z fumiyas $
+# $Id$
 
 # This script can help you setting up the smbldap_conf.pl file. It will set all
 # the default values that are defined in the smb.conf configuration file. You 
@@ -22,10 +22,9 @@
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-#  USA.
+#  You should have received a copy of the GNU General Public License along
+#  with this program; if not, write to the Free Software Foundation, Inc.,
+#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 use strict;
 use warnings;
@@ -204,18 +203,15 @@ my $userHomeDirectoryMode=read_entry(". default users' homeDirectory mode","","7
 
 my $userScript=read_entry(". default user netlogon script (use %U as username)","logonscript","",0);
 
-my $defaultMaxPasswordAge=read_entry("  default password validation time (time in days)","","45",0);
+my $defaultMaxPasswordAge=read_entry(". default password validation time (time in days)","","45",0);
 
 #############################
 # ldap directory parameters #
 #############################
 my $ldap_suffix=read_entry(". ldap suffix","ldapsuffix","",0);
 my $ldap_group_suffix=read_entry(". ldap group suffix","ldapgroupsuffix","",0);
-$ldap_group_suffix=~s/ou=//;
 my $ldap_user_suffix=read_entry(". ldap user suffix","ldapusersuffix","",0);
-$ldap_user_suffix=~s/ou=//;
 my $ldap_machine_suffix=read_entry(". ldap machine suffix","ldapmachinesuffix","",0);
-$ldap_machine_suffix=~s/ou=//;
 my $ldap_idmap_suffix=read_entry(". Idmap suffix","ldapidmapsuffix","ou=Idmap",0);
 print ". sambaUnixIdPooldn: object where you want to store the next uidNumber\n";
 print "  and gidNumber available for new users and groups\n";
@@ -276,14 +272,15 @@ chomp $sid_tmp;
 print ". SID for domain $config{workgroup}: SID of the domain (can be obtained with 'net getlocalsid $netbios_name')\n";
 my $sid=read_entry("  SID for domain $config{workgroup}","","$sid_tmp",0);
 
-print ". unix password encryption: encryption used for unix passwords\n";
-my $cryp_algo=read_entry("  unix password encryption (CRYPT, MD5, SMD5, SSHA, SHA)","","SSHA",0);
-my $crypt_salt_format="";
-if ( $cryp_algo eq "CRYPT" ) {
-  print ". crypt salt format: If hash_encrypt is set to CRYPT, you may set \n";
+print ". unix password hash: hash used for unix passwords\n";
+print "  If set to \"exop\", use LDAPv3 Password Modify (RFC 3062) extended operation.\n";
+my $password_hash=read_entry("  unix password hash (CRYPT, MD5, SMD5, SSHA, SHA, CLEARTEXT)","","SSHA",0);
+my $password_crypt_salt_format="";
+if ( $password_hash eq "CRYPT" ) {
+  print ". password crypt salt format: If password_hash is set to CRYPT, you may set \n";
   print "  a salt format. The default is \"\%s\", but many systems will generate\n";
   print "  MD5 hashed passwords if you use \"\$1\$\%\.8s\"\n";
-  $crypt_salt_format=read_entry("  crypt salt format","","\%s",0);
+  $password_crypt_salt_format=read_entry("  password crypt salt format","","\%s",0);
 }
 
 my $default_user_gidnumber=read_entry(". default user gidNumber","","513",0);
@@ -296,6 +293,8 @@ my $skeletonDir=read_entry(". default skeleton directory","","/etc/skel",0);
 
 my $mailDomain=read_entry(". default domain name to append to mail address", "","",0);
 
+my $shadowAccount=read_entry(". treat shadowAccount object or not (1/0)","","1",0);
+
 print "-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=\n";
 my $template_smbldap="
 # smbldap-tools.conf : Q & D configuration file for smbldap-tools
@@ -399,17 +398,17 @@ suffix=\"$ldap_suffix\"
 # Where are stored Users
 # Ex: usersdn=\"ou=Users,dc=IDEALX,dc=ORG\"
 # Warning: if 'suffix' is not set here, you must set the full dn for usersdn
-usersdn=\"ou=$ldap_user_suffix,\${suffix}\"
+usersdn=\"$ldap_user_suffix,\${suffix}\"
 
 # Where are stored Computers
 # Ex: computersdn=\"ou=Computers,dc=IDEALX,dc=ORG\"
 # Warning: if 'suffix' is not set here, you must set the full dn for computersdn
-computersdn=\"ou=$ldap_machine_suffix,\${suffix}\"
+computersdn=\"$ldap_machine_suffix,\${suffix}\"
 
 # Where are stored Groups
 # Ex: groupsdn=\"ou=Groups,dc=IDEALX,dc=ORG\"
 # Warning: if 'suffix' is not set here, you must set the full dn for groupsdn
-groupsdn=\"ou=$ldap_group_suffix,\${suffix}\"
+groupsdn=\"$ldap_group_suffix,\${suffix}\"
 
 # Where are stored Idmap entries (used if samba is a domain member server)
 # Ex: groupsdn=\"ou=Idmap,dc=IDEALX,dc=ORG\"
@@ -425,13 +424,14 @@ sambaUnixIdPooldn=\"$sambaUnixIdPooldn,\${suffix}\"
 # Default scope Used
 scope=\"sub\"
 
-# Unix password encryption (CRYPT, MD5, SMD5, SSHA, SHA, CLEARTEXT)
-hash_encrypt=\"$cryp_algo\"
+# Unix password hash scheme (CRYPT, MD5, SMD5, SSHA, SHA, CLEARTEXT)
+# If set to \"exop\", use LDAPv3 Password Modify (RFC 3062) extended operation.
+password_hash=\"$password_hash\"
 
-# if hash_encrypt is set to CRYPT, you may set a salt format.
+# if password_hash is set to CRYPT, you may set a salt format.
 # default is \"\%s\", but many systems will generate MD5 hashed
 # passwords if you use \"\$1\$\%\.8s\". This parameter is optional!
-crypt_salt_format=\"$crypt_salt_format\"
+password_crypt_salt_format=\"$password_crypt_salt_format\"
 
 ##############################################################################
 # 
@@ -463,6 +463,9 @@ defaultComputerGid=\"$default_computer_gidnumber\"
 # Skel dir
 skeletonDir=\"$skeletonDir\"
 
+# Treat shadowAccount object or not
+shadowAccount=\"$shadowAccount\"
+
 # Default password validation time (time in days) Comment the next line if
 # you don't want password to be enable for defaultMaxPasswordAge days (be
 # careful to the sambaPwdMustChange attribute's value)
@@ -557,3 +560,21 @@ print "  $smbldap_bind_conf done.\n";
 $mode=0600;
 chmod $mode,"$smbldap_bind_conf","$smbldap_bind_conf.old";
 
+__END__
+
+=head1 NAME
+
+smbldap-config - Configure the smbldap-tools
+
+=head1 SYNOPSIS
+
+smbldap-config
+
+=head1 DESCRIPTION
+
+An interactive script to configure the smbldap-tools to work with your
+existing LDAP server(s). Before running it, you should ensure that your
+samba controller is up and running, and that the domain SID is defined
+(you can check it by running 'net getlocalsid').
+
+=cut
