@@ -1,6 +1,6 @@
 #!@PERL_COMMAND@
 
-# $Id: smbldap-useradd.pl 151 2012-10-24 02:04:28Z fumiyas $
+# $Id$
 
 #  This code was developed by Jerome Tournier (jtournier@gmail.com) and
 #  contributors (their names can be found in the CONTRIBUTORS file).
@@ -27,8 +27,6 @@ use warnings;
 
 use FindBin qw($RealBin);
 use smbldap_tools;
-use Crypt::SmbHash;
-#####################
 
 use Getopt::Long;
 my %Options;
@@ -215,8 +213,13 @@ my $userUidNumber = $Options{'u'};
 if ( !defined($userUidNumber) ) {
     $userUidNumber = user_next_uid();
 }
-elsif (!$Options{non_unique} and my $user = user_by_uid($userUidNumber)) {
-    die "UID already owned by " . $user->dn . "\n";
+elsif (!$Options{non_unique}) {
+    if (my $user = user_by_uid($userUidNumber)) {
+	die "UID already owned by " . $user->dn . "\n";
+    }
+    if (my @pwent = getpwuid($userUidNumber)) {
+	die "UID already owned by $pwent[0]\n";
+    }
 }
 
 my $createGroup   = 0;
@@ -350,7 +353,7 @@ if (   defined( $Options{'w'} )
             print "New passwords don't match!\n";
             exit(10);
         }
-        my ( $lmpassword, $ntpassword ) = ntlmgen $pass;
+        my ($lmpassword, $ntpassword) = password_hash_samba($pass);
         my $date   = time;
         my $modify = $ldap_master->modify(
             "uid=$userName,$config{computersdn}",
@@ -418,7 +421,6 @@ my @attr = (
     'homeDirectory' => $userHomeDirectory,
     'loginShell'    => $config{userLoginShell},
     'gecos'         => $config{userGecos},
-    'userPassword'  => "{crypt}x"
 );
 
 push(@objectclass, 'shadowAccount') if ($config{shadowAccount});
@@ -430,7 +432,7 @@ unless ($Options{'b'}) {
 }
 
 my $add = $ldap_master->add("uid=$userName,$config{usersdn}", attr => \@attr);
-$add->code && warn "failed to add entry: ", $add->error;
+$add->code && die "failed to add entry: ", $add->error;
 
 #if ($createGroup) {
 #    group_add($userName, $userGidNumber);
@@ -577,13 +579,13 @@ if ( defined( $Options{'a'} ) ) {
 
     }
     else {
-        my $FILE = "|$config{smbpasswd} -s -a $userName >/dev/null";
-        open( FILE, $FILE ) || die "$!\n";
-        print FILE <<EOF;
-x
-x
-EOF
-        close FILE;
+	my $pass;
+	$pass .= chr(rand(0x7F-0x20)+0x20) for (1..32);
+	open my $fh, "|-"
+	    or exec($config{smbpasswd}, "-s", "-a", $userName)
+	    || die "Failed to execute smbpasswd: $!";
+	$fh->print("$pass\n$pass\n");
+	$fh->close;
         if ($?) {
             print "$0: error adding samba account\n";
             exit(10);
