@@ -1,6 +1,6 @@
 #!@PERL_COMMAND@
 
-# $Id: smbldap_tools.pl 150 2012-10-24 02:04:10Z fumiyas $
+# $Id$
 
 #  This code was developped by Jerome Tournier (jtournier@gmail.com) and
 #  contributors (their names can be found in the CONTRIBUTORS file).
@@ -106,11 +106,12 @@ use vars qw(%config $ldap);
   split_arg_comma
   list_union
   list_minus
+  account_base_rid
   account_by_sid
   user_by_uid
   user_next_uid
   user_next_rid
-  group_next_uid
+  group_next_gid
   group_next_rid
   print_banner
   getDomainName
@@ -119,6 +120,7 @@ use vars qw(%config $ldap);
   utf8Decode
   password_read
   password_set
+  password_hash_samba
   shadow_update
   nsc_invalidate
   %config
@@ -244,7 +246,9 @@ sub read_smbconf {
 my %smbconf = read_smbconf();
 
 sub getLocalSID {
-    open my $fh, "-|" or exec("$samba_bindir/net", "getlocalsid") || exit(1);
+    open my $fh, "-|"
+	or exec("$samba_bindir/net", "getlocalsid")
+	|| die "Failed to execute net: $!";
 
     my $line = <$fh>;
     if (!defined($line)) {
@@ -268,6 +272,7 @@ sub getLocalSID {
     password_hash =>		'SSHA',
     password_crypt_salt_format=>'%s',
     shadowAccount =>		true,
+    lanmanPassword =>		false,
     nscd =>			"/usr/sbin/nscd",
     userHomeDirectoryMode =>	"0700",
     read_conf(),
@@ -635,7 +640,7 @@ sub add_samba_machine {
     my $name     = $user;
     $name =~ s/.$//s;
 
-    my ( $lmpassword, $ntpassword ) = ntlmgen $name;
+    my ($lmpassword, $ntpassword) = password_hash_samba($name);
     my $modify = $ldap->modify(
         "uid=$user,$config{computersdn}",
         changes => [
@@ -1582,6 +1587,16 @@ sub password_salt
     return join "", @seeds[map {rand scalar(@seeds)} (1..$length)];
 }
 
+sub password_hash_samba
+{
+    my ($pass) = @_;
+
+    my ($lmpass, $ntpass) = ntlmgen($pass);
+    $lmpass = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX" unless ($config{lanmanPassword});
+
+    return ($lmpass, $ntpass);
+}
+
 sub shadow_update
 {
     if (!$config{shadowAccount}) {
